@@ -6,19 +6,26 @@
 #
 # maintained by the
 # @author Chart Group at Geodetic Fundamental Station Wettzell (Chart@fs.wettzell.de)
-# @date 2011-11-25
-# @version 2.4.3
+# @date 2012-10-03
+# @version 2.4.6
+#
+
+## @class Chart::LinesPoints
+# LinesPoints class connect the given x-/y-values by straight lines and the x-/y-values are plotted by points.
+#
+# This class provides all functions which are specific to
+# lines
 #
 
 package Chart::LinesPoints;
 
-use Chart::Base '2.4.3';
+use Chart::Base '2.4.6';
 use GD;
 use Carp;
 use strict;
 
 @Chart::LinesPoints::ISA     = qw(Chart::Base);
-$Chart::LinesPoints::VERSION = '2.4.3';
+$Chart::LinesPoints::VERSION = '2.4.6';
 
 #>>>>>>>>>>>>>>>>>>>>>>>>>>#
 #  public methods go here  #
@@ -86,17 +93,22 @@ sub _draw_data
     #for a xy-plot, use this delta and maybe an offset for the zero-axes
     if ( $self->true( $self->{'xy_plot'} ) )
     {
-        $diff      = ( $self->{'x_max_val'} - $self->{'x_min_val'} );
-        $diff      = 1 if $diff == 0;
-        $delta_num = $width / ( $self->{'x_max_val'} - $self->{'x_min_val'} );
-
-        if ( $self->{'x_min_val'} <= 0 && $self->{'x_max_val'} >= 0 )
+        my ( $xmin, $xmax ) = ( $self->{'x_min_val'}, $self->{'x_max_val'} );
+        if ( $self->{'xlabels'} )
         {
-            $zero_offset = abs( $self->{'x_min_val'} ) * abs($delta_num);
+            ( $xmin, $xmax ) = @{ $self->{'xrange'} };
         }
-        elsif ( $self->{'x_min_val'} > 0 || $self->{'x_max_val'} < 0 )
+        $diff      = $xmax - $xmin;
+        $diff      = 1 if $diff == 0;
+        $delta_num = $width / $diff;
+
+        if ( $xmin <= 0 && $xmax >= 0 )
         {
-            $zero_offset = -$self->{'x_min_val'} * $delta_num;
+            $zero_offset = abs($xmin) * abs($delta_num);
+        }
+        elsif ( $xmin > 0 || $xmax < 0 )
+        {
+            $zero_offset = -$xmin * $delta_num;
         }
         else
         {
@@ -110,7 +122,7 @@ sub _draw_data
 
         # get the color for this dataset, and set the brush
         $color = $self->_color_role_to_index( 'dataset' . ( $i - 1 ) );
-        $brush = $self->_prepare_brush( $color, 'line' );
+        $brush = $self->_prepare_brush( $color, 'line', 'dataset' . ( $i - 1 ) );
         $self->{'gd_obj'}->setBrush($brush);
 
         # draw every line for this dataset
@@ -178,7 +190,7 @@ sub _draw_data
         }
 
         # reset the brush for points
-        $brush = $self->_prepare_brush( $color, 'point' );
+        $brush = $self->_prepare_brush( $color, 'point', 'dataset' . ( $i - 1 ) );
         $self->{'gd_obj'}->setBrush($brush);
 
         # draw every point for this dataset
@@ -335,83 +347,5 @@ sub _draw_data
 
 }
 
-## @fn private _prepare_brush
-#  set the gdBrush object to trick GD into drawing fat lines
-sub _prepare_brush
-{
-    my $self  = shift;
-    my $color = shift;
-    my $type  = shift;
-    my ( $radius, @rgb, $brush, $white, $newcolor );
-
-    # get the rgb values for the desired color
-    @rgb = $self->{'gd_obj'}->rgb($color);
-
-    # get the appropriate brush size
-    if ( $type eq 'line' )
-    {
-        $radius = $self->{'brush_size'} / 2;
-    }
-    elsif ( $type eq 'point' )
-    {
-        $radius = $self->{'pt_size'} / 2;
-    }
-
-    # create the new image
-    $brush = GD::Image->new( $radius * 2, $radius * 2 );
-
-    # get the colors, make the background transparent
-    $white = $brush->colorAllocate( 255, 255, 255 );
-    $newcolor = $brush->colorAllocate(@rgb);
-    $brush->transparent($white);
-
-    # draw a nice object
-    if ( $self->{'brushStyle'} eq 'OpenCircle' )
-    {
-
-        # draw the circle
-        $brush->arc( $radius - 1, $radius - 1, $radius, $radius, 0, 360, $newcolor );
-    }
-    elsif ( $self->{'brushStyle'} eq 'FilledDiamond' )
-    {
-
-        # draw the diamond, using 1 oint less than maximum
-        my $R  = int( $radius + 0.5 );
-        my $R2 = $R * 2;
-        $brush->line( $R,  1,       $R2 - 1, $R,      $newcolor );
-        $brush->line( $R2, $R,      $R,      $R2 - 1, $newcolor );
-        $brush->line( $R,  $R2 - 1, 1,       $R,      $newcolor );
-        $brush->line( 1,   $R,      $R,      1,       $newcolor );
-
-        # and fill it
-        $brush->fill( $radius - 1, $radius - 1, $newcolor );
-    }
-    elsif ( $self->{'brushStyle'} eq 'OpenDiamond' )
-    {
-
-        # draw the diamond, using 1 oint less than maximum
-        my $R  = int( $radius + 0.5 );
-        my $R2 = $R * 2;
-        $brush->line( $R,  1,       $R2 - 1, $R,      $newcolor );
-        $brush->line( $R2, $R,      $R,      $R2 - 1, $newcolor );
-        $brush->line( $R,  $R2 - 1, 1,       $R,      $newcolor );
-        $brush->line( 1,   $R,      $R,      1,       $newcolor );
-    }
-    else
-    {
-
-        # in all other cases:
-
-        # draw the circle
-        $brush->arc( $radius - 1, $radius - 1, $radius, $radius, 0, 360, $newcolor );
-
-        # and fill it
-        $brush->fill( $radius - 1, $radius - 1, $newcolor );
-    }
-
-    # set the new image as the main object's brush
-    return $brush;
-}
-
 ## be a good module and return 1
 1;
